@@ -41,7 +41,7 @@ class MetaMax extends CMSModule
 
   function GetVersion()
   {
-    return '2.1.3.3';
+    return '2.1.4';
   }
 
   function GetHelp()
