@@ -18,6 +18,13 @@ $curcontent =& $curnode->GetContent();
 $modified_date = $curcontent->GetModifiedDate();
 $modified_date = date('Y-m-d\TH:i:sP',$modified_date);
 $currentYear = date('Y');
+
+$countVars = '';
+$countVars2 = '';
+$canonical = '';
+$pageMeta = '';
+$meta_block = '';
+
 if ($this->GetPreference('meta_block_title','') != '') {
     $meta_block = str_replace(' ','_',$this->GetPreference('meta_block_title',''));
 } else {
@@ -282,7 +289,6 @@ if ($this->GetPreference('allow_add',1) == 1) {
    $this->smarty->assign('descriptions_title', $this->GetPreference('descriptions_title',''));
    $this->smarty->assign('keywordson_title', $this->GetPreference('keywordson_title','1'));
    $this->smarty->assign('keywords_title', $skipwords);
-   $this->smarty->assign('blobber', $blobber);
    $this->smarty->assign('keywords_default', $this->GetPreference('key_default',''));
    $this->smarty->assign('keywords_smarty', $smarty->get_template_vars($key_smarty));
    $this->smarty->assign('keyskip_title', $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very, every, been, with, then, this, will, don\'t'));
